"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = ResolverString;

var _ducky = require("ducky");

var _ducky2 = _interopRequireDefault(_ducky);

var _graphql = require("graphql");

var GraphQL = _interopRequireWildcard(_graphql);

var _language = require("graphql/language");

var GraphQLLanguage = _interopRequireWildcard(_language);

var _error = require("graphql/error");

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*  String resolver for GraphQL Tools  */
/*
**  GraphQL-Tools-Types -- Custom Scalar Types for GraphQL-Tools
**  Copyright (c) 2016-2018 Ralf S. Engelschall <rse@engelschall.com>
**
**  Permission is hereby granted, free of charge, to any person obtaining
**  a copy of this software and associated documentation files (the
**  "Software"), to deal in the Software without restriction, including
**  without limitation the rights to use, copy, modify, merge, publish,
**  distribute, sublicense, and/or sell copies of the Software, and to
**  permit persons to whom the Software is furnished to do so, subject to
**  the following conditions:
**
**  The above copyright notice and this permission notice shall be included
**  in all copies or substantial portions of the Software.
**
**  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
**  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
**  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
**  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
**  CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
**  TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
**  SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

/*  external requirements  */
function ResolverString(options = {}) {
    let errors = [];
    if (!_ducky2.default.validate(options, "{ name: string, min?: number, max?: number, regex?: RegExp, fn?: function }", errors)) throw new _error.GraphQLError("[graphql-tools-types] " + `invalid parameters: ${errors.join("; ")}`, []);
    const validate = (value, ast = null) => {
        if (options.min !== undefined && value.length < options.min) throw new _error.GraphQLError(`[graphql-tools-types] ${options.name}: ` + `minimum length is ${options.min}`, ast !== null ? [ast] : []);
        if (options.max !== undefined && value.length > options.max) throw new _error.GraphQLError(`[graphql-tools-types] ${options.name}: ` + `maximum length is ${options.max}`, ast !== null ? [ast] : []);
        if (options.regex !== undefined && !options.regex.test(value)) throw new _error.GraphQLError(`[graphql-tools-types] ${options.name}: ` + `value does not match ${options.regex}`, ast !== null ? [ast] : []);
        if (options.fn !== undefined && !options.fn(value)) throw new _error.GraphQLError(`[graphql-tools-types] ${options.name}: ` + "value not valid", ast !== null ? [ast] : []);
    };
    return {
        /*  serialize value sent as output to the client  */
        __serialize: value => {
            return value;
        },

        /*  parse value received as input from client  */
        __parseValue: value => {
            if (typeof value !== "string") throw new _error.GraphQLError(`[graphql-tools-types] ${options.name}: ` + "invalid input value (type \"string\" expected)", []);
            validate(value);
            return value;
        },

        /*  parse value received as literal in AST  */
        __parseLiteral: ast => {
            if (ast.kind !== GraphQLLanguage.Kind.STRING) throw new _error.GraphQLError(`[graphql-tools-types] ${options.name}: ` + "invalid AST node (kind \"STRING\" expected)", [ast]);
            let value = GraphQL.GraphQLString.parseLiteral(ast);
            validate(value, ast);
            return value;
        }
    };
}
